@@ -7,6 +7,10 @@
         <location filename="mainwindow.ui" line="14"/>
         <source>Theme Customizer</source>
         <translation>Theme Customizer</translation>
+    </message>    
+    <message>
+        <source>Tune transitions</source>
+        <translation></translation>
     </message>
     <message>
         <source>Theme</source>
